@@ -97,6 +97,14 @@ class Settings : public QSettings
     Q_PROPERTY(bool signedInToAccounts
                READ getSignedInToAccounts
                NOTIFY signedInToAccountsChanged)
+    Q_PROPERTY(bool showRelatedVideos
+               READ getShowRelatedVideos
+               WRITE setShowRelatedVideos
+               NOTIFY showRelatedVideosChanged)
+    Q_PROPERTY(int maximumFlickVelocity
+               READ getMaximumFlickVelocity
+               WRITE setMaximumFlickVelocity
+               NOTIFY maximumFlickVelocityChanged)
 
 public:
     explicit Settings(QSettings *parent = 0);
@@ -125,6 +133,8 @@ public:
     QString getXTubeDownloadPath() const { return xtubeDownloadPath; }
     QString getUploadAttribute() const { return uploadAttribute; }
     bool getSignedInToAccounts() { return signedInToAccounts; }
+    bool getShowRelatedVideos() { return showRelatedVideos; }
+    int getMaximumFlickVelocity() { return maximumFlickVelocity; }
 
 signals:
     void youtubeDownloadQualityChanged(const QString &quality);
@@ -158,6 +168,8 @@ signals:
     void uploadAttributeChanged();
     void xtubeQualityChanged(const QString &quality);
     void signedInToAccountsChanged();
+    void showRelatedVideosChanged();
+    void maximumFlickVelocityChanged();
 
 public slots:
     void saveSettings();
@@ -190,6 +202,8 @@ public slots:
     void clearTwitterAccount();
     void setUploadAttribute(const QString &attribute);
     void signInToAccounts();
+    void setShowRelatedVideos(bool show);
+    void setMaximumFlickVelocity(int velocity);
 
 private:
     void setXTubeEnabled(bool enabled);
@@ -232,6 +246,8 @@ private:
     QString uploadAttribute;
     QString xtubeQuality;
     bool signedInToAccounts;
+    bool showRelatedVideos;
+    int maximumFlickVelocity;
 };
 
 #endif // SETTINGS_H
