@@ -615,25 +615,22 @@ void YouTube::parseVideoPage(QNetworkReply *reply) {
 
     QMap<int, QString> formats;
     QString response(QByteArray::fromPercentEncoding(reply->readAll()));
-    if (!response.contains("fmt_stream_map=url=")) {
+    if (!response.contains("url_encoded_fmt_stream_map=")) {
         emit alert(tr("Unable to retrieve video. Access may be restricted"));
         emit videoUrlError();
     }
     else {
-        response = response.split("fmt_stream_map=url=").at(1);
-        QStringList parts = response.split(QRegExp(",url=|&url="));
+        response = response.section("url_encoded_fmt_stream_map=", 1, 1);
+        QStringList parts = response.split("itag=", QString::SkipEmptyParts);
         QString part;
-        QStringList keySplit;
         QString url;
         int key;
         for (int i = 0; i < parts.length(); i++) {
             part = parts[i];
-            url = QByteArray::fromPercentEncoding(part.left(part.indexOf("c.youtube.com&") + 13).toAscii()).replace("%2C", ",");
-            keySplit = part.split("&itag=");
-            if (keySplit.size() > 1) {
-                key = keySplit.at(1).split(QRegExp("[&,]")).first().toInt();
-                formats[key] = url;
-            }
+            key = part.left(part.indexOf('&')).toInt();
+            url = part.section("url=", 1, -1);
+            url = QByteArray::fromPercentEncoding(url.section("&quality", 0, 0).toUtf8()).replace("%2C", ",").replace("sig=", "signature=");
+            formats[key] = url;
         }
         QList<int> flist;
         flist << pbMap.value("360p") << pbMap.value("hq");
